@@ -16,7 +16,7 @@ class FileSystem(object):
     def rmdir(self, path):
         pass  # not necessary to implement, may not have directories
 
-    def ls(self, path, detail=True, **kwargs):
+    def ls(self, path="", detail=True, **kwargs):
         """
         List files.  Returns a list of entries with these fields:
           'name' - full path to the entry (without protocol)
