@@ -85,25 +85,6 @@ class DSLibraryViaMMLibrary(DSLibrary):
                 raise FileNotFoundError(f"not found: {path}")
         raise DSLibraryException(f"Unsupported mode: {mode}")
 
-    def get_filesystem_connection(self, resource_name: str, for_write: bool=False, **kwargs):
-        open_method = self._find_method("open_stream")
-        if not open_method:
-            raise DSLibraryException(f"No filesystem engine access available, requested={resource_name}")
-        bucket = kwargs.get("bucket")
-        file_source = f"{resource_name}:{bucket}" if bucket else resource_name
-        class MMFS(FileSystem):
-            def ls(self, path, detail=True, **kwargs):
-                raise NotImplementedError()
-            def rm(self, path, recursive=False, maxdepth=None):
-                raise NotImplementedError()
-            def mkdir(self, path, create_parents=True, **kwargs):
-                raise NotImplementedError()
-            def stat(self, path, **kwargs):
-                raise NotImplementedError()
-            def open(self, path, mode="rb", block_size=None, cache_options=None, **kwargs):
-                return open_method(path, file_source=file_source, mode=mode)
-        return MMFS()
-
     def open_model_binary(self, part: str=None, mode: str='rb') -> io.RawIOBase:
         """
         The model-binary is just one file, but we can support 'part' by assuming it is a ZIP file.
@@ -168,25 +149,23 @@ class DSLibraryViaMMLibrary(DSLibrary):
         method = self._find_method("return_score", "returnScore")
         method(score)
 
-    def get_sql_connection(self, resource_name: str, for_write: bool=False, database: str=None, **kwargs):
-        method = self._find_method("get_db_connection", "getDBConnection")
-        sig = inspect.signature(method)
-        params = {}
-        if database:
-            if "database" in sig.parameters:
-                # TODO this parameter is deprecated--let's not create open-ended connections that can access any db
-                params["database"] = database
-            else:
-                raise DSLibraryException("The 'database' parameter is not supported by this implementation of get_db_connection()")
-        return method(resource_name, **params)
-
     def _get_system_connection(self, system_type, resource_name: str, for_write: bool=False, **kwargs):
         """
-        All types of connection can be accessed through mmlibrary.get_db_connection() (some day it will change to
-        'get_connection()').
+        All types of connection can be accessed through mmlibrary.get_db_connection().
         """
-        method = self._find_method("get_db_connection")
-        return method(resource_name, read_only=not for_write)
+        # anything with a protocol can hopefully be handled by the built-in logic
+        uri, _ = self._xlt_resource(resource_name, "outputs" if for_write else "inputs", **kwargs)
+        if ":" in uri:
+            return super(DSLibraryViaMMLibrary, self)._get_system_connection(system_type, resource_name, for_write, **kwargs)
+        # ordinary 'named' connections go through this method to build a proxy to a remote system
+        method = self._find_method("get_db_connection", mandatory=True)
+        sig = inspect.signature(method)
+        more = {}
+        if "_expected_system_type" in sig.parameters:
+            more["_expected_system_type"] = system_type
+        if "_read_only" in sig.parameters:
+            more["_read_only"] = not for_write
+        return method(resource_name, **more)
 
     def install_packages(self, packages: list, verbose: bool=False):
         method = self._find_method("install_packages")
